==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/web/kotlin/inputs/ConnectionStatusDefinitionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.web.kotlin.inputs

import com.pulumi.azurenative.web.inputs.ConnectionStatusDefinitionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Connection status
 * @property error Connection error
 * @property status The gateway status
 * @property target Target of the error
 */
public data class ConnectionStatusDefinitionArgs(
    public val error: Output<ConnectionErrorArgs>? = null,
    public val status: Output<String>? = null,
    public val target: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.web.inputs.ConnectionStatusDefinitionArgs> {
    override fun toJava(): com.pulumi.azurenative.web.inputs.ConnectionStatusDefinitionArgs =
        com.pulumi.azurenative.web.inputs.ConnectionStatusDefinitionArgs.builder()
            .error(error?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .status(status?.applyValue({ args0 -> args0 }))
            .target(target?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ConnectionStatusDefinitionArgs].
 */
@PulumiTagMarker
public class ConnectionStatusDefinitionArgsBuilder internal constructor() {
    private var error: Output<ConnectionErrorArgs>? = null

    private var status: Output<String>? = null

    private var target: Output<String>? = null

    /**
     * @param value Connection error
     */
    @JvmName("lxyqjeojgbxaisbo")
    public suspend fun error(`value`: Output<ConnectionErrorArgs>) {
        this.error = value
    }

    /**
     * @param value The gateway status
     */
    @JvmName("vhhkpwpeqnjsbmbp")
    public suspend fun status(`value`: Output<String>) {
        this.status = value
    }

    /**
     * @param value Target of the error
     */
    @JvmName("stwwhwbxibstvoix")
    public suspend fun target(`value`: Output<String>) {
        this.target = value
    }

    /**
     * @param value Connection error
     */
    @JvmName("lammlxdyliksvtyj")
    public suspend fun error(`value`: ConnectionErrorArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.error = mapped
    }

    /**
     * @param argument Connection error
     */
    @JvmName("tmvhoucecfrhqkbx")
    public suspend fun error(argument: suspend ConnectionErrorArgsBuilder.() -> Unit) {
        val toBeMapped = ConnectionErrorArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.error = mapped
    }

    /**
     * @param value The gateway status
     */
    @JvmName("wnnyhgsftrqmikom")
    public suspend fun status(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.status = mapped
    }

    /**
     * @param value Target of the error
     */
    @JvmName("xgopgicgiwtxihob")
    public suspend fun target(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.target = mapped
    }

    internal fun build(): ConnectionStatusDefinitionArgs = ConnectionStatusDefinitionArgs(
        error = error,
        status = status,
        target = target,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/web/kotlin/inputs/ConnectionStatusDefinitionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.web.kotlin.inputs

import com.pulumi.azurenative.web.inputs.ConnectionStatusDefinitionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Connection status
 * @property error Connection error
 * @property status The gateway status
 * @property target Target of the error
 */
public data class ConnectionStatusDefinitionArgs(
    public val error: Output<ConnectionErrorArgs>? = null,
    public val status: Output<String>? = null,
    public val target: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.web.inputs.ConnectionStatusDefinitionArgs> {
    override fun toJava(): com.pulumi.azurenative.web.inputs.ConnectionStatusDefinitionArgs =
        com.pulumi.azurenative.web.inputs.ConnectionStatusDefinitionArgs.builder()
            .error(error?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .status(status?.applyValue({ args0 -> args0 }))
            .target(target?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ConnectionStatusDefinitionArgs].
 */
@PulumiTagMarker
public class ConnectionStatusDefinitionArgsBuilder internal constructor() {
    private var error: Output<ConnectionErrorArgs>? = null

    private var status: Output<String>? = null

    private var target: Output<String>? = null

    /**
     * @param value Connection error
     */
    @JvmName("denedhmevwkhbnib")
    public suspend fun error(`value`: Output<ConnectionErrorArgs>) {
        this.error = value
    }

    /**
     * @param value The gateway status
     */
    @JvmName("ivllrolrfncdvrsh")
    public suspend fun status(`value`: Output<String>) {
        this.status = value
    }

    /**
     * @param value Target of the error
     */
    @JvmName("miufhksiitcjlkqn")
    public suspend fun target(`value`: Output<String>) {
        this.target = value
    }

    /**
     * @param value Connection error
     */
    @JvmName("aghqeiehbragtenv")
    public suspend fun error(`value`: ConnectionErrorArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.error = mapped
    }

    /**
     * @param argument Connection error
     */
    @JvmName("bjoqswoxftlnjttq")
    public suspend fun error(argument: suspend ConnectionErrorArgsBuilder.() -> Unit) {
        val toBeMapped = ConnectionErrorArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.error = mapped
    }

    /**
     * @param value The gateway status
     */
    @JvmName("visyeffckyspaxix")
    public suspend fun status(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.status = mapped
    }

    /**
     * @param value Target of the error
     */
    @JvmName("gfbjaegdhpxusaak")
    public suspend fun target(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.target = mapped
    }

    internal fun build(): ConnectionStatusDefinitionArgs = ConnectionStatusDefinitionArgs(
        error = error,
        status = status,
        target = target,
    )
}
